@@ -380,6 +380,36 @@ _string_array_to_char_array (char	*dst,
 }
 #endif
 
+#if defined (HAVE_COGL_1_8) && !defined (HAVE_CLUTTER_OSX)
+static gint
+get_n_fragment_texture_units (void)
+{
+  ClutterBackend *backend;
+  CoglContext *context;
+  CoglDisplay *display;
+  CoglRenderer *renderer;
+  gint n;
+
+  backend = clutter_get_default_backend ();
+  context = clutter_backend_get_cogl_context (backend);
+  display = cogl_context_get_display (context);
+  renderer = cogl_display_get_renderer (display);
+
+  n = cogl_renderer_get_n_fragment_texture_units (renderer);
+
+  return n;
+}
+#else
+static gint
+get_n_fragment_texture_units (void)
+{
+  gint n_texture_units;
+
+  glGetIntegerv (GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS, &n_texture_units);
+  return n_texture_units;
+}
+#endif
+
 static CoglHandle
 _create_cogl_program (const char *source)
 {
@@ -796,7 +826,7 @@ clutter_gst_build_renderers_list (void)
       NULL
     };
 
-  glGetIntegerv (GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS, &nb_texture_units);
+  nb_texture_units = get_n_fragment_texture_units();
 
   if (nb_texture_units >= 3)
     features |= CLUTTER_GST_MULTI_TEXTURE;
@@ -998,7 +1028,7 @@ clutter_gst_video_sink_set_caps (GstBaseSink *bsink,
   const GValue               *par;
   gint                        width, height;
   guint32                     fourcc;
-  int                         red_mask, blue_mask;
+  guint                       red_mask, blue_mask;
 
   sink = CLUTTER_GST_VIDEO_SINK(bsink);
   priv = sink->priv;
@@ -1064,8 +1094,8 @@ clutter_gst_video_sink_set_caps (GstBaseSink *bsink,
   else
     {
       guint32 mask;
-      gst_structure_get_int (structure, "red_mask", &red_mask);
-      gst_structure_get_int (structure, "blue_mask", &blue_mask);
+      gst_structure_get_uint (structure, "red_mask", &red_mask);
+      gst_structure_get_uint (structure, "blue_mask", &blue_mask);
 
       mask = red_mask | blue_mask;
       if (mask < 0x1000000)
